TwapAlgorithm

Struct TwapAlgorithm 

pub struct TwapAlgorithm {
    pub core: ExecutionAlgorithmCore,
    /* private fields */
}
Time-Weighted Average Price (TWAP) execution algorithm.

Executes orders by evenly spreading them over a specified time horizon, at regular intervals. The algorithm receives a primary order and spawns smaller child orders that are executed at regular intervals.

Fields

core: ExecutionAlgorithmCore

The algorithm core.

Implementations

Source

impl TwapAlgorithm

pub fn new(config: TwapAlgorithmConfig) -> Self

Creates a new TwapAlgorithm instance.